@@ -151,7 +151,6 @@ static int check_fd(struct tslib_input *i)
 	rc = fcntl(ts->fd, F_GETFL);
 	if (rc == -1) {
 		perror("fcntl");
-		free(i);
 		return -1;
 	}
 	if (rc & O_NONBLOCK) {
@@ -174,7 +173,6 @@ static int check_fd(struct tslib_input *i)
 	rc = libevdev_new_from_fd(ts->fd, &i->evdev);
 	if (rc < 0) {
 		fprintf(stderr, "Failed to init libevdev (%s)\n", strerror(-rc));
-		free(i);
 		return -1;
 	}
 
@@ -381,6 +379,9 @@ static int ts_input_read(struct tslib_module_info *inf,
 	int total = 0;
 	int pen_up = 0;
 
+	if (!i)
+		return -ENOMEM;
+
 	if (ts->fd != i->last_fd)
 		i->last_fd = check_fd(i);
 
@@ -556,6 +557,9 @@ static int ts_input_read_mt(struct tslib_module_info *inf,
 	static int32_t next_trackid;
 	struct input_event ev;
 
+	if (!i)
+		return -ENOMEM;
+
 	if (ts->fd != i->last_fd)
 		i->last_fd = check_fd(i);
 
@@ -564,10 +568,9 @@ static int ts_input_read_mt(struct tslib_module_info *inf,
 
 	if (i->buf == NULL || i->max_slots < max_slots || i->nr < nr) {
 		if (i->buf) {
-			for (j = 0; j < i->nr; j++) {
-				if (i->buf[j])
-					free(i->buf[j]);
-			}
+			for (j = 0; j < i->nr; j++)
+				free(i->buf[j]);
+
 			free(i->buf);
 		}
 
@@ -699,7 +702,7 @@ static int ts_input_read_mt(struct tslib_module_info *inf,
 				}
 				i->last_type_a_slots = i->slot;
 
-				/* FIXME this pen_up is deprectated in MT */
+				/* FIXME this pen_up is deprecated in MT */
 				if (pen_up)
 					pen_up = 0;
 
@@ -878,15 +881,11 @@ static int ts_input_fini(struct tslib_module_info *inf)
 
 	libevdev_free(i->evdev);
 
-	for (j = 0; j < i->nr; j++) {
-		if (i->buf[j])
-			free(i->buf[j]);
-	}
-	if (i->buf)
-		free(i->buf);
+	for (j = 0; j < i->nr; j++)
+		free(i->buf[j]);
 
-	if (i->last_pressure)
-		free(i->last_pressure);
+	free(i->buf);
+	free(i->last_pressure);
 
 	free(inf);
 
