@@ -584,10 +584,9 @@ static int ts_input_read_mt(struct tslib_module_info *inf,
 
 	if (i->buf == NULL || i->max_slots < max_slots || i->nr < nr) {
 		if (i->buf) {
-			for (j = 0; j < i->nr; j++) {
-				if (i->buf[j])
-					free(i->buf[j]);
-			}
+			for (j = 0; j < i->nr; j++)
+				free(i->buf[j]);
+
 			free(i->buf);
 		}
 
@@ -700,7 +699,7 @@ static int ts_input_read_mt(struct tslib_module_info *inf,
 					}
 					i->last_type_a_slots = i->slot;
 
-					/* FIXME this pen_up is deprectated in MT */
+					/* FIXME this pen_up is deprecated in MT */
 					if (pen_up)
 						pen_up = 0;
 
@@ -903,15 +902,11 @@ static int ts_input_fini(struct tslib_module_info *inf)
 			fprintf(stderr, "tslib: Unable to un-grab selected input device\n");
 	}
 
-	for (j = 0; j < i->nr; j++) {
-		if (i->buf[j])
-			free(i->buf[j]);
-	}
-	if (i->buf)
-		free(i->buf);
+	for (j = 0; j < i->nr; j++)
+		free(i->buf[j]);
 
-	if (i->last_pressure)
-		free(i->last_pressure);
+	free(i->buf);
+	free(i->last_pressure);
 
 	free(inf);
 
