@@ -45,6 +45,9 @@ static const struct tslib_module_desc tslib_modules[] = {
 #ifdef TSLIB_STATIC_CORGI_MODULE
 	{ "corgi", corgi_mod_init },
 #endif
+#ifdef TSLIB_STATIC_CROP_MODULE
+	{ "crop", crop_mod_init },
+#endif
 #ifdef TSLIB_STATIC_CY8MRLN_PALMPRE_MODULE
 	{ "cy8mrln_palmpre", cy8mrln_palmpre_mod_init },
 #endif
@@ -141,6 +144,7 @@ static struct tslib_module_info *__ts_load_module_static(struct tsdev *ts,
 	struct tslib_module_desc key;
 
 	key.name = module;
+	key.mod_init = NULL;
 	result = bsearch(&key, tslib_modules, countof(tslib_modules),
 			 sizeof(struct tslib_module_desc), cmp_name);
 	if (!result)
