@@ -311,7 +311,7 @@ int main(int argc, char **argv)
 		int ret;
 
 		if (samples) {
-			if (samples >= have_samples)
+			if (have_samples >= samples)
 				goto out;
 
 			have_samples++;
@@ -427,20 +427,13 @@ out:
 		ts_close(ts);
 
 	if (samp_mt) {
-		if (samp_mt[0])
-			free(samp_mt[0]);
-
+		free(samp_mt[0]);
 		free(samp_mt);
 	}
 
-	if (x)
-		free(x);
-
-	if (y)
-		free(y);
-
-	if (mode_mt)
-		free(mode_mt);
+	free(x);
+	free(y);
+	free(mode_mt);
 
 	return 0;
 }
