@@ -133,10 +133,11 @@ static void ts_verify_free_mt(struct ts_verify *data)
 	if (!data->samp_mt)
 		return;
 
-	for (i = 0; i < data->nr; i++) {
-		if (data->samp_mt[i])
-			free(data->samp_mt[i]);
-	}
+	for (i = 0; i < data->nr; i++)
+		free(data->samp_mt[i]);
+	free(data->samp_mt);
+	data->samp_mt = NULL;
+
 	ts_close(data->ts);
 }
 
@@ -213,12 +214,10 @@ static int ts_verify_read_1(struct ts_verify *data, int nr,
 {
 	int ret;
 
+	data->samp_read = calloc(nr, sizeof(struct ts_sample));
 	if (!data->samp_read) {
-		data->samp_read = calloc(nr, sizeof(struct ts_sample));
-		if (!data->samp_read) {
-			perror("calloc");
-			return errno;
-		}
+		perror("calloc");
+		return errno;
 	}
 
 	data->ts = ts_setup(data->tsdevice, nonblocking);
@@ -250,7 +249,6 @@ static int ts_verify_read_1(struct ts_verify *data, int nr,
 
 	ts_close(data->ts);
 	free(data->samp_read);
-	data->samp_read = NULL;
 
 	return ret;
 }
@@ -297,7 +295,7 @@ static void run_tests(struct ts_verify *data)
 
 	printf("===================== test run %d =====================\n", data->iteration);
 
-	/* ts_read() paramters(data, samples, nonblocking, raw) */
+	/* ts_read() parameters(data, samples, nonblocking, raw) */
 	ret = ts_verify_read_mt_1(data, 1, 0, 0);
 	data->read_mt_run_count++;
 	if (ret <= 1 && ret >= 0) {
