@@ -612,15 +612,16 @@ static int process(struct data_t *data, struct ts_sample_mt **s_array,
 		if (data->verbose) {
 			for (j = 0; j < nr; j++) {
 				printf(BLUE DEFAULT_UINPUT_NAME
-				       ": sample %d:  x\ty\tslot\ttracking_id\n"
+				       ": sample %d:  x\ty\tslot\tpressure\ttracking_id\n"
 				       RESET, j);
 				for (i = 0; i < max_slots; i++) {
 					if (s_array[j][i].valid & TSLIB_MT_VALID) {
 						printf(DEFAULT_UINPUT_NAME
-						       ": \t%d\t%d\t%d\t%d\n",
+						       ": \t%d\t%d\t%d\t%d\t%d\n",
 						       s_array[j][i].x,
 						       s_array[j][i].y,
 						       s_array[j][i].slot,
+						       s_array[j][i].pressure,
 						       s_array[j][i].tracking_id);
 					}
 				}
@@ -646,14 +647,12 @@ static void cleanup(struct data_t *data)
 
 	if (data->s_array) {
 		for (i = 0; i < TS_READ_WHOLE_SAMPLES; i++) {
-			if (data->s_array[i])
-				free(data->s_array[i]);
+			free(data->s_array[i]);
 		}
 		free(data->s_array);
 	}
 
-	if (data->ev)
-		free(data->ev);
+	free(data->ev);
 
 	if (data->fd_uinput > 0) {
 		ret = ioctl(data->fd_uinput, UI_DEV_DESTROY);
@@ -669,8 +668,7 @@ static void cleanup(struct data_t *data)
 	if (data->fd_fb)
 		close(data->fd_fb);
 
-	if (data->uinput_name)
-		free(data->uinput_name);
+	free(data->uinput_name);
 }
 
 /* directly from libevdev (LGPL) */
@@ -709,15 +707,17 @@ static char *get_new_path(struct data_t *data)
 	struct dirent **namelist;
 	const char *path = "/dev/input/";
 	int ndev;
+	int maxndev;
 	int fd;
 	char buf[256];
 	int ret;
 	char *devnode = NULL;
 
-	ndev = scandir(path, &namelist, is_event_device, alphasort);
-	if (ndev <= 0)
+	maxndev = scandir(path, &namelist, is_event_device, alphasort);
+	if (maxndev <= 0)
 		return NULL;
 
+	ndev = maxndev;
 	while (ndev--) {
 		if (asprintf(&devnode, "/dev/input/%s", namelist[ndev]->d_name) == -1) {
 			devnode = NULL;
@@ -725,29 +725,34 @@ static char *get_new_path(struct data_t *data)
 		}
 
 		fd = open(devnode, O_RDWR);
-		if (fd == -1)
-			return NULL;
+		if (fd == -1) {
+			free(devnode);
+			devnode = NULL;
+			break;
+		}
 
 		ret = ioctl(fd, EVIOCGNAME(sizeof(buf) - 1), buf);
 		if (ret < 0) {
 			close(fd);
 			free(devnode);
+			devnode = NULL;
 			break;
 		}
 
 		ret = strncmp(buf, data->uinput_name, strlen(data->uinput_name));
-		if (ret == 0) {
-			close(fd);
-			free(namelist[ndev]);
-			break;
-		}
-
 		close(fd);
-		free(namelist[ndev]);
+		if (ret == 0)
+			break;
+
 		free(devnode);
+		devnode = NULL;
 	}
 
+	/* free also the one that is currently active */
+	while (maxndev--)
+		free(namelist[maxndev]);
 	free(namelist);
+
 	return devnode;
 }
 
@@ -1041,8 +1046,7 @@ int main(int argc, char **argv)
 	}
 
 out:
-	if (dev_input_name)
-		free(dev_input_name);
+	free(dev_input_name);
 
 	cleanup(&data);
 
